@@ -14,11 +14,14 @@ use Wikibase::Datatype::Struct::Value::Monolingual;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
 
+	if (! defined $obj) {
+		err "Object doesn't exist.";
+	}
 	if (! $obj->isa('Wikibase::Datatype::Item')) {
 		err "Object isn't 'Wikibase::Datatype::Item'.";
 	}
@@ -151,15 +154,15 @@ sub struct2obj {
 	my $obj = Wikibase::Datatype::Item->new(
 		'aliases' => $aliases_ar,
 		'descriptions' => $descriptions_ar,
-		'id' => $struct_hr->{'id'},
+		$struct_hr->{'id'} ? ('id' => $struct_hr->{'id'}) : (),
 		'labels' => $labels_ar,
-		'lastrevid' => $struct_hr->{'lastrevid'},
-		'modified' => $struct_hr->{'modified'},
-		'ns' => $struct_hr->{'ns'},
-		'page_id' => $struct_hr->{'pageid'},
+		$struct_hr->{'lastrevid'} ? ('lastrevid' => $struct_hr->{'lastrevid'}) : (),
+		$struct_hr->{'modified'} ? ('modified' => $struct_hr->{'modified'}) : (),
+		$struct_hr->{'ns'} ? ('ns' => $struct_hr->{'ns'}) : (),
+		$struct_hr->{'pageid'} ? ('page_id' => $struct_hr->{'pageid'}) : (),
 		'sitelinks' => $sitelinks_ar,
 		'statements' => $statements_ar,
-		'title' => $struct_hr->{'title'},
+		$struct_hr->{'title'} ? ('title' => $struct_hr->{'title'}) : (),
 	);
 
 	return $obj;
@@ -212,6 +215,7 @@ Returns Wikibase::Datatype::Item instance.
 
  obj2struct():
          Base URI is required.
+         Object doesn't exist.
          Object isn't 'Wikibase::Datatype::Item'.
 
 =head1 EXAMPLE1
@@ -824,6 +828,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
