@@ -10,11 +10,14 @@ use Wikibase::Datatype::Value::Monolingual;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub obj2struct {
 	my $obj = shift;
 
+	if (! defined $obj) {
+		err "Object doesn't exist.";
+	}
 	if (! $obj->isa('Wikibase::Datatype::Value::Monolingual')) {
 		err "Object isn't 'Wikibase::Datatype::Value::Monolingual'.";
 	}
@@ -83,6 +86,7 @@ Returns Wikibase::Datatype::Value::Monolingual instance.
 =head1 ERRORS
 
  obj2struct():
+         Object doesn't exist.
          Object isn't 'Wikibase::Datatype::Value::Monolingual'.
 
 =head1 EXAMPLE1
@@ -190,6 +194,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
