@@ -11,11 +11,14 @@ use Wikibase::Datatype::Struct::Utils qw(obj_array_ref2struct struct2snaks_array
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
 
+	if (! defined $obj) {
+		err "Object doesn't exist.";
+	}
 	if (! $obj->isa('Wikibase::Datatype::Reference')) {
 		err "Object isn't 'Wikibase::Datatype::Reference'.";
 	}
@@ -85,6 +88,7 @@ Returns Wikibase::Datatype::Reference instance.
 
  obj2struct():
          Base URI is required.
+         Object doesn't exist.
          Object isn't 'Wikibase::Datatype::Reference'.
 
 =head1 EXAMPLE1
@@ -302,6 +306,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
