@@ -12,11 +12,14 @@ use Wikibase::Datatype::Struct::Statement;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
 
+	if (! defined $obj) {
+		err "Object doesn't exist.";
+	}
 	if (! $obj->isa('Wikibase::Datatype::Sense')) {
 		err "Object isn't 'Wikibase::Datatype::Sense'.";
 	}
@@ -119,6 +122,7 @@ Returns Wikibase::Datatype::Sense instance.
 
  obj2struct():
          Base URI is required.
+         Object doesn't exist.
          Object isn't 'Wikibase::Datatype::Sense'.
 
 =head1 EXAMPLE1
@@ -312,6 +316,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
