@@ -11,11 +11,14 @@ use Wikibase::Datatype::Value::Globecoordinate;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
 
+	if (! defined $obj) {
+		err "Object doesn't exist.";
+	}
 	if (! $obj->isa('Wikibase::Datatype::Value::Globecoordinate')) {
 		err "Object isn't 'Wikibase::Datatype::Value::Globecoordinate'.";
 	}
@@ -111,6 +114,7 @@ Returns Wikibase::Datatype::Value::Globecoordinate instance.
 
  obj2struct():
          Base URI is required.
+         Object doesn't exist.
          Object isn't 'Wikibase::Datatype::Value::Globecoordinate'.
 
  struct2obj():
@@ -244,6 +248,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
