@@ -10,11 +10,14 @@ use Wikibase::Datatype::Value::Property;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub obj2struct {
 	my $obj = shift;
 
+	if (! defined $obj) {
+		err "Object doesn't exist.";
+	}
 	if (! $obj->isa('Wikibase::Datatype::Value::Property')) {
 		err "Object isn't 'Wikibase::Datatype::Value::Property'.";
 	}
@@ -96,6 +99,7 @@ Returns Wikibase::Datatype::Value::Property instance.
 =head1 ERRORS
 
  obj2struct():
+         Object doesn't exist.
          Object isn't 'Wikibase::Datatype::Value::Property'.
 
  struct2obj():
@@ -204,6 +208,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
